@@ -14,10 +14,10 @@ class About:
 	def open(self, ignore):
 		dialog = gtk.AboutDialog()
 		dialog.set_name("Bluetooth Coffeemaker")
-		dialog.set_logo_icon_name("general_bluetooth")
+		dialog.set_logo_icon_name("bluetooth-coffeemaker")
 		dialog.set_authors(["Olli Laasonen [admin@laasonen.net]", "Niko Kauppila [nkauppila@gmail.com]",""])
 		dialog.set_comments("Team Panda's Bluetooth Coffeemaker")
-		dialog.set_version("0.1")
+		dialog.set_version("0.1.0")
 		dialog.set_license("This program is free software; you can redistribute it and/or\nmodify it under the terms of the GNU General Public License\nas published by the Free Software Foundation; either version 2\nof the License, or (at your option) any later version.")
 		dialog.set_copyright("(c) Team Panda")
 		dialog.set_website("http://teampanda.com/")
